@@ -1,11 +1,12 @@
 from __future__ import unicode_literals, division, absolute_import
 import logging
 from datetime import datetime, timedelta
+
 from sqlalchemy import Column, Integer, String, Unicode, DateTime, ForeignKey, and_, Index
 from sqlalchemy.orm import relation
-from flexget import db_schema
+
+from flexget import db_schema, plugin
 from flexget.event import event
-from flexget.plugin import register_plugin, register_parser_option, priority
 from flexget.utils.sqlalchemy_utils import table_columns, drop_tables, table_add_column
 from flexget.utils.tools import parse_timedelta
 
@@ -18,16 +19,8 @@ def upgrade(ver, session):
     if ver is None:
         columns = table_columns('remember_rejected_entry', session)
         if 'uid' in columns:
-            # Drop the old table
-            log.info('Dropping old version of remember_rejected_entry table from db')
-            drop_tables(['remember_rejected_entry'], session)
-            # Create new table from the current model
-            Base.metadata.create_all(bind=session.bind)
-            # We go directly to version 2, as remember_rejected_entries table has just been made from current model
-            # TODO: Fix this somehow. Just avoid dropping tables?
-            ver = 3
-        else:
-            ver = 0
+            raise db_schema.UpgradeImpossible
+        ver = 0
     if ver == 0:
         log.info('Adding reason column to remember_rejected_entry table.')
         table_add_column('remember_rejected_entry', 'reason', String, session)
@@ -80,17 +73,13 @@ class FilterRememberRejected(object):
         entry.reject('message', remember=True)
     """
 
-    @priority(0)
+    @plugin.priority(0)
     def on_task_start(self, task, config):
         """Purge remembered entries if the config has changed."""
         # See if the task has changed since last run
         old_task = task.session.query(RememberTask).filter(RememberTask.name == task.name).first()
-        if not task.is_rerun and old_task and (task.config_modified or task.manager.options.forget_rejected):
-            if task.manager.options.forget_rejected:
-                log.info('Forgetting previous rejections.')
-                task.config_changed()
-            else:
-                log.debug('Task config has changed since last run, purging remembered entries.')
+        if not task.is_rerun and old_task and task.config_modified:
+            log.debug('Task config has changed since last run, purging remembered entries.')
             task.session.delete(old_task)
             old_task = None
         if not old_task:
@@ -105,12 +94,12 @@ class FilterRememberRejected(object):
                 task.config_changed()
         task.session.commit()
 
-    @priority(-255)
+    @plugin.priority(-255)
     def on_task_input(self, task, config):
         for entry in task.all_entries:
             entry.on_reject(self.on_entry_reject, task=task)
 
-    @priority(255)
+    @plugin.priority(255)
     def on_task_filter(self, task, config):
         """Reject any remembered entries from previous runs"""
         (task_id,) = task.session.query(RememberTask.id).filter(RememberTask.name == task.name).first()
@@ -158,6 +147,6 @@ def db_cleanup(session):
         log.verbose('Removed %d entries from remember rejected table.' % result)
 
 
-register_plugin(FilterRememberRejected, 'remember_rejected', builtin=True, api_ver=2)
-register_parser_option('--forget-rejected', action='store_true', dest='forget_rejected',
-                       help='Forget all previous rejections so entries can be processed again.')
+@event('plugin.register')
+def register_plugin():
+    plugin.register(FilterRememberRejected, 'remember_rejected', builtin=True, api_ver=2)
